@@ -16,16 +16,14 @@
 #' @examples
 #' data(Nile)
 #' find_regimes(log(Nile), iter = 50, chains = 1, max_regimes = 2)
-
 find_regimes <- function(y,
-  sds = NULL,
-  min_regimes = 1,
-  max_regimes = 3,
-  iter = 2000,
-  thin = 1,
-  chains = 1,
-  ...) {
-
+                         sds = NULL,
+                         min_regimes = 1,
+                         max_regimes = 3,
+                         iter = 2000,
+                         thin = 1,
+                         chains = 1,
+                         ...) {
   df <- data.frame(regimes = seq(min_regimes, max_regimes), looic = NA)
   best_loo <- 1.0e10
   best_model <- NA
@@ -35,9 +33,15 @@ find_regimes <- function(y,
       chains = chains, ...
     )
     looic <- loo.bayesdfa(fit)
-    loo_bad <- loo::pareto_k_table(looic)["(0.7, 1]","Count"]
-    loo_very_bad <- loo::pareto_k_table(looic)["(1, Inf)","Count"]
-    df$looic[which(df$regimes == regime)] = looic$estimates["looic", "Estimate"]
+    k_table <- loo::pareto_k_table(looic)
+    if (nrow(k_table) == 4) {
+      loo_bad <- k_table["(0.7, 1]", "Count"]
+      loo_very_bad <- k_table["(1, Inf)", "Count"]
+    } else {
+      loo_bad <- k_table[2, "Count"]
+      loo_very_bad <- k_table[3, "Count"]
+    }
+    df$looic[which(df$regimes == regime)] <- looic$estimates["looic", "Estimate"]
 
     if (fit$looic < best_loo) {
       best_loo <- fit$looic
@@ -47,6 +51,8 @@ find_regimes <- function(y,
     }
   }
 
-  list(table = df, best_model = best_model, n_loo_bad = n_loo_bad,
-    n_loo_very_bad = n_loo_very_bad)
+  list(
+    table = df, best_model = best_model, n_loo_bad = n_loo_bad,
+    n_loo_very_bad = n_loo_very_bad
+  )
 }
