@@ -16,6 +16,12 @@
 #' @param varIndx Indices of unique observation variances. Defaults to `c(1, 1,
 #'   1, 1)`. Unique observation error variances would be specified as `c(1, 2, 3,
 #'   4)` in the case of 4 time series.
+#' @param trend_model The type of trend model. Random walk (`"rw"`) or basis
+#'   spline (`"bs"`)
+#' @param spline_weights A matrix of basis function weights that is used
+#'   if `trend_model = "bs"`. The number of columns should correspond to
+#'   the number of knots and the number of rows should correspond to the
+#'   number of trends.
 #' @param extreme_value Value added to the random walk in the extreme time step.
 #'   Defaults to not included.
 #' @param extreme_loc Location of single extreme event in the process. The same
@@ -31,6 +37,7 @@
 #'   the underlying trends, `Z` is the manipulated loadings matrix that is fed
 #'   to the model.
 #' @importFrom stats rlnorm rnorm rt
+#' @importFrom splines splineDesign
 #' @examples
 #' x <- sim_dfa(num_trends = 2)
 #' names(x)
@@ -61,12 +68,16 @@ sim_dfa <- function(num_trends = 1,
                     ),
                     sigma = rlnorm(1, meanlog = log(0.2), 0.1),
                     varIndx = rep(1, num_ts),
+                    trend_model = c("rw", "bs"),
+                    spline_weights = matrix(ncol = 6, nrow = num_trends,
+                      data = rnorm(6 * num_trends)),
                     extreme_value = NULL,
                     extreme_loc = NULL,
                     nu_fixed = 100,
                     user_supplied_deviations = NULL) {
   y_ignore <- matrix(rnorm(num_ts * num_years), nrow = num_ts, ncol = num_years)
 
+  trend_model <- match.arg(trend_model)
   d <- fit_dfa(y_ignore,
     num_trends = num_trends, estimation = "none", scale = "center",
     varIndx = varIndx, nu_fixed = nu_fixed, trend_model = "rw"
@@ -87,34 +98,54 @@ sim_dfa <- function(num_trends = 1,
 
   x <- matrix(nrow = d$sampling_args$data$K, ncol = d$sampling_args$data$N) # random walk-trends
 
-  # initial state for each trend
-  for (k in seq_len(d$sampling_args$data$K)) {
-    if (!is.null(user_supplied_deviations)) {
-      devs <- user_supplied_deviations[, k]
-    } else {
-      devs <- rt(d$sampling_args$data$N, df = d$sampling_args$data$nu_fixed)
-    }
-
-    x[k, 1] <- rnorm(1, 0, 1)
-    if (is.null(extreme_value)) {
-      for (t in seq(2, d$sampling_args$data$N)) {
-        x[k, t] <- x[k, t - 1] + devs[t] # random walk
-      }
-    } else {
-      if (is.null(extreme_loc)) extreme_loc <- round(num_years / 2)
-      for (t in 2:(extreme_loc - 1)) {
-        x[k, t] <- x[k, t - 1] + devs[t] # random walk
-      }
-      # only include extreme in first trend
-      if (k == 1) {
-        x[1, extreme_loc] <- x[1, extreme_loc - 1] + extreme_value
+  if (trend_model == "rw") {
+    # initial state for each trend
+    for (k in seq_len(d$sampling_args$data$K)) {
+      if (!is.null(user_supplied_deviations)) {
+        devs <- user_supplied_deviations[, k]
       } else {
-        x[k, extreme_loc] <- x[k, extreme_loc - 1] + devs[t]
+        devs <- rt(d$sampling_args$data$N, df = d$sampling_args$data$nu_fixed)
       }
-      for (t in seq(extreme_loc + 1, d$sampling_args$data$N)) {
-        x[k, t] <- x[k, t - 1] + devs[t] # random walk
+
+      x[k, 1] <- rnorm(1, 0, 1)
+      if (is.null(extreme_value)) {
+        for (t in seq(2, d$sampling_args$data$N)) {
+          x[k, t] <- x[k, t - 1] + devs[t] # random walk
+        }
+      } else {
+        if (is.null(extreme_loc)) extreme_loc <- round(num_years / 2)
+        for (t in 2:(extreme_loc - 1)) {
+          x[k, t] <- x[k, t - 1] + devs[t] # random walk
+        }
+        # only include extreme in first trend
+        if (k == 1) {
+          x[1, extreme_loc] <- x[1, extreme_loc - 1] + extreme_value
+        } else {
+          x[k, extreme_loc] <- x[k, extreme_loc - 1] + devs[t]
+        }
+        for (t in seq(extreme_loc + 1, d$sampling_args$data$N)) {
+          x[k, t] <- x[k, t - 1] + devs[t] # random walk
+        }
       }
     }
+  } else if (trend_model == "bs") {
+    # num_years <- 25
+    # spline_weights <- matrix(ncol = 7, nrow = 3, data = rnorm(21))
+    df <- ncol(spline_weights)
+    degree <- 3
+    intercept <- 1L
+    # adapted from splines::bs
+    ord <- 1 + degree
+    Boundary.knots <- c(1, num_years)
+    nIknots <- df - ord + (1L - intercept)
+    knots <- seq(0, 1, length.out = nIknots + 2L)[-c(1L, nIknots + 2L)]
+    knots <- quantile(seq(1, num_years), knots)
+    Aknots <- sort(c(rep(Boundary.knots, ord), knots))
+    X_spline <- t(splineDesign(Aknots, x = seq(1, num_years), ord))
+    x <- spline_weights %*% X_spline
+    # matplot(t(x), type = "l", lty = 1)
+  } else {
+    stop("Trend model not defined", call. = FALSE)
   }
 
   pred <- Z %*% x
